@@ -146,7 +146,7 @@ Creating tmp file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>More info: http://mnemosyne-proj.sourceforge.net
+        <source>More info: http://mnemosyne-proj.org
 </source>
         <translation type="unfinished"></translation>
     </message>
@@ -374,7 +374,7 @@ Creating tmp file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>&amp;Preview</source>
+        <source>Preview</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -488,13 +488,17 @@ Creating tmp file.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Number of grade 0 cards to learn at once:</source>
+        <source>Number of grade 0 cards to hold in your hand:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>&amp;OK</source>
         <translation type="unfinished"></translation>
@@ -707,6 +711,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>To edit a card, right-click on it.</source>
         <translation type="unfinished"></translation>
@@ -895,7 +903,7 @@ so you might want to run </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Show &amp;answer</source>
+        <source>Show answer</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1370,6 +1378,34 @@ Happy learning!</source>
         <source>Grade</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1397,6 +1433,10 @@ Happy learning!</source>
         <source>Categories</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <source>&amp;OK</source>
         <translation type="unfinished"></translation>
