@@ -151,7 +151,13 @@ Vytvářím tmp soubor.</translation>
     <message>
         <source>More info: http://mnemosyne-proj.sourceforge.net
 </source>
-        <translation>Více informací: http://mnemosyne-proj.sourceforge.net
+        <translation type="obsolete">Více informací: http://mnemosyne-proj.sourceforge.net
+</translation>
+    </message>
+    <message>
+        <source>More info: http://mnemosyne-proj.org
+</source>
+        <translation>Více informací: http://mnemosyne-proj.org
 </translation>
     </message>
 </context>
@@ -381,7 +387,7 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>&amp;Náhled</translation>
+        <translation type="obsolete">&amp;Náhled</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -395,6 +401,10 @@ Vytvářím tmp soubor.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation>Náhled</translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -495,7 +505,7 @@ Vytvářím tmp soubor.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Počet karet s hodnocením 0 pro okamžité učení:</translation>
+        <translation type="obsolete">Počet karet s hodnocením 0 pro okamžité učení:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -513,6 +523,14 @@ Vytvářím tmp soubor.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Zrušit</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation>Učit se nové kartičky v náhodném pořadí</translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -728,6 +746,10 @@ takže by jste potom měl(a) provést </translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation>Alt+F</translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -905,7 +927,7 @@ takže by jste potom měl(a) provést </translation>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Ukázat &amp;odpověď</translation>
+        <translation type="obsolete">Ukázat &amp;odpověď</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -931,6 +953,10 @@ takže by jste potom měl(a) provést </translation>
         <source>All: </source>
         <translation>Všech: </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation>Ukázat odpověď</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1343,7 +1369,7 @@ O ukládání vaší práce se starat nemusíte, to já budu dělat automaticky.
 &lt;p&gt;
 Nejlepších výsledků dosáhnete, pokud budete opakovat každý den. Budu ale dělat, co je v mých silách i pokud opakování odložíte nebo se rozhodnete naučit se něco navíc.
 &lt;p&gt;
-Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
+Další dokumentace viz. http://mnemosyne-proj.org
 &lt;p&gt;
 Šťastné učení!</translation>
     </message>
@@ -1421,6 +1447,34 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
         <source>Grade</source>
         <translation>Hodnocení</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation>Není žádná aktuální karta</translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation>Hodnocení:</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation>Jednoduchost:</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation>Opakování:</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation>Zapomenutí:</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation>Dnů od posledního opakování:</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation>Dnů do dalšího opakování:</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1452,6 +1506,10 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation>Aktuální karta</translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
@@ -1529,7 +1587,7 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>The best way to backup your data is to copy your .mnemosyne directory (if you follow the recommended procedure to keep all your files there) and move it to a different drive. Mnemosyne keeps automatic XML-based backups in .mnemosyne/backups, but that won&apos;t help you if that drive dies... </source>
-        <translation type="unfinished">Nejlepší cestou k zálohování vašich dat je kopírovat váš .mnemosyne adresář (za předpokladu, že se držíte doporučení a máte všechny soubory v tomto adresáři) na jiný disk. Mnemosyne sice automaticky vytváří XML zálohy v .mnemosyne/backups, to vám ale při poruše disku nebude moc platné. </translation>
+        <translation>Nejlepší cestou k zálohování vašich dat je kopírovat váš .mnemosyne adresář (za předpokladu, že se držíte doporučení a máte všechny soubory v tomto adresáři) na jiný disk. Mnemosyne sice automaticky vytváří XML zálohy v .mnemosyne/backups, to vám ale při poruše disku nebude moc platné. </translation>
     </message>
     <message>
         <source>You can run Mnemosyne from a USB key. Copy C:\Program Files\Mnemosyne to your USB key, and then copy the .mnemosyne directory from your home directory to inside the Mnemosyne directory on the USB key.</source>
@@ -1545,11 +1603,11 @@ Další dokumentace viz. http://www.mnemosyne-proj.sourceforge.net.
     </message>
     <message>
         <source>If you want more fine-grained control over LaTeX&apos;s behaviour, see the explanation of the &lt;$$&gt;...&lt;/$$&gt; and &lt;latex&gt;...&lt;/latex&gt; tags on Mnemosyne&apos;s website.</source>
-        <translation type="unfinished">Více informací o LaTeXu v Mnemosyne najdete zde http://mnemosyne-proj.sourceforge.net/faq.php</translation>
+        <translation>Více informací o LaTeXu v Mnemosyne najdete na www stránkách Mnemosyne.</translation>
     </message>
     <message>
         <source>Advanced users can customise more of Mnemosyne by editing the config.py file in their .mnemosyne directory. They can also install plugins to customise Mnemosyne even further.</source>
-        <translation>Pokročilí uživatelé si mohou nastavit Mnemosyne editací souboru config.py ve .mnemosyne adresáři. Je možné také instalovat pluginy, které dále mění chování Mnemosyne.</translation>
+        <translation>Pokročilí uživatelé si mohou nastavit Mnemosyne editací souboru config.py v .mnemosyne adresáři. Je možné také instalovat pluginy, které dále mění chování Mnemosyne.</translation>
     </message>
 </context>
 <context>
