@@ -505,7 +505,7 @@ Creando un archivo temporal.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Número de tarjetas con puntuación 0 a aprender de una vez:</translation>
+        <translation type="obsolete">Número de tarjetas con puntuación 0 a aprender de una vez:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -527,6 +527,10 @@ Creando un archivo temporal.</translation>
         <source>Learn new cards in random order</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
