@@ -154,9 +154,14 @@ Création d&apos;un fichier tmp.</translation>
     <message>
         <source>More info: http://mnemosyne-proj.sourceforge.net
 </source>
-        <translation>Plus d&apos;information : http://mnemosyne-proj.sourceforge.net
+        <translation type="obsolete">Plus d&apos;information : http://mnemosyne-proj.sourceforge.net
 </translation>
     </message>
+    <message>
+        <source>More info: http://mnemosyne-proj.org
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutFrm</name>
@@ -385,7 +390,7 @@ Création d&apos;un fichier tmp.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>A&amp;perçu</translation>
+        <translation type="obsolete">A&amp;perçu</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -399,6 +404,10 @@ Création d&apos;un fichier tmp.</translation>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -499,7 +508,7 @@ Création d&apos;un fichier tmp.</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>Nombres de cartes de note 0 à apprendre à la fois :</translation>
+        <translation type="obsolete">Nombres de cartes de note 0 à apprendre à la fois :</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -517,6 +526,14 @@ Création d&apos;un fichier tmp.</translation>
         <source>&amp;Cancel</source>
         <translation>&amp;Annuler</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -697,6 +714,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation>Re&amp;chercher</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -732,6 +753,10 @@ so you might want to run </source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -909,7 +934,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>Afficher la &amp;réponse</translation>
+        <translation type="obsolete">Afficher la &amp;réponse</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -935,6 +960,10 @@ so you might want to run </source>
         <source>All: </source>
         <translation>Total : </translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">Afficher la réponse</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1421,6 +1450,34 @@ Joyeux apprentissage!</translation>
         <source>Grade</source>
         <translation>Note</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">Note :</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">Facilité :</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">Répétitions :</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">Oubils :</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">Jours depuis la dernière répétition :</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">Jours jusqu&apos;à la prochaine répétition :</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1452,6 +1509,10 @@ Joyeux apprentissage!</translation>
         <source>&amp;OK</source>
         <translation>&amp;OK</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
