@@ -502,7 +502,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>מספר הכרטיסיות עם ציון 0 ללמוד בבת אחת (אחת אחרי השנייה):</translation>
+        <translation type="obsolete">מספר הכרטיסיות עם ציון 0 ללמוד בבת אחת (אחת אחרי השנייה):</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -524,6 +524,10 @@ Creating tmp file.</source>
         <source>Learn new cards in random order</source>
         <translation>למד כרטיסיות חדשות בסדר אקראי</translation>
     </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
