@@ -177,7 +177,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Select the categories to activate:</source>
-        <translation>選択するカテゴリーを選択してください:</translation>
+        <translation>カテゴリーを選択してください:</translation>
     </message>
     <message>
         <source>Activate none</source>
@@ -185,7 +185,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Activate all</source>
-        <translation>全部を選択する</translation>
+        <translation>すべてを選択</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -245,7 +245,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Duplicate not added.</source>
-        <translation>同じカードは追加しませんでした。</translation>
+        <translation>同じカードを追加しませんでした。</translation>
     </message>
     <message>
         <source>&amp;OK</source>
@@ -272,7 +272,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>&amp;Do not add</source>
-        <translation>&amp;記入しない</translation>
+        <translation>&amp;追加しない</translation>
     </message>
 </context>
 <context>
@@ -299,7 +299,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Add &amp;vice versa too</source>
-        <translation>&amp;逆も追加する</translation>
+        <translation>&amp;逆カード（答え・質問順番）も追加する</translation>
     </message>
     <message>
         <source>Alt+V</source>
@@ -307,7 +307,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Select initial grade:</source>
-        <translation>最初の評価:</translation>
+        <translation>最初のグレード:</translation>
     </message>
     <message>
         <source>&amp;0</source>
@@ -383,7 +383,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Type question and answer, then pick initial grade.</source>
-        <translation>質問と答えを記入して、最初の評価を選択する.</translation>
+        <translation>質問と答えを記入して、最初のグレードを選択する.</translation>
     </message>
     <message>
         <source>&amp;Preview</source>
@@ -403,7 +403,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Preview</source>
-        <translation type="unfinished"></translation>
+        <translation>プレービュー</translation>
     </message>
 </context>
 <context>
@@ -505,7 +505,7 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>グレード０カードの枚数の同時習得:</translation>
+        <translation type="obsolete">グレード０カードの枚数の同時習得:</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -525,6 +525,10 @@ TMPファイルを使っています。</translation>
     </message>
     <message>
         <source>Learn new cards in random order</source>
+        <translation>新しいカードを無作為順番で習う</translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
@@ -742,7 +746,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Alt+F</source>
-        <translation type="unfinished"></translation>
+        <translation>Alt+F</translation>
     </message>
 </context>
 <context>
@@ -925,7 +929,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
-        <translation>カードをスケジュールした日より早く復習する（すすめじゃない）</translation>
+        <translation>カードをスケジュールより早く復習する（おすすめではない）</translation>
     </message>
     <message>
         <source>Pick days until next repetition:</source>
@@ -949,7 +953,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show answer</source>
-        <translation type="unfinished">答えを表示</translation>
+        <translation>答えを表示</translation>
     </message>
 </context>
 <context>
@@ -1429,7 +1433,7 @@ Happy learning!</source>
         <source>Number of cards with the following grades:
 
 </source>
-        <translation>下記のグレードのカードの枚数: 
+        <translation>カードのグレードの枚数: 
 </translation>
     </message>
     <message>
@@ -1438,31 +1442,31 @@ Happy learning!</source>
     </message>
     <message>
         <source>No current card.</source>
-        <translation type="unfinished"></translation>
+        <translation>カードが選択されていない.</translation>
     </message>
     <message>
         <source>Grade:</source>
-        <translation type="unfinished">評価:</translation>
+        <translation>グレード:</translation>
     </message>
     <message>
         <source>Easiness:</source>
-        <translation type="unfinished">やさしさ:</translation>
+        <translation>やさしさ:</translation>
     </message>
     <message>
         <source>Repetitions:</source>
-        <translation type="unfinished">何回見せた:</translation>
+        <translation>何回見せた:</translation>
     </message>
     <message>
         <source>Lapses:</source>
-        <translation type="unfinished">何回忘れた:</translation>
+        <translation>何回忘れた:</translation>
     </message>
     <message>
         <source>Days since last repetition:</source>
-        <translation type="unfinished">復習した日から何日:</translation>
+        <translation>復習した日から何日:</translation>
     </message>
     <message>
         <source>Days until next repetition:</source>
-        <translation type="unfinished">もう一度復習する日まで何日:</translation>
+        <translation>もう一度復習する日まで何日:</translation>
     </message>
 </context>
 <context>
@@ -1497,7 +1501,7 @@ Happy learning!</source>
     </message>
     <message>
         <source>Current card</source>
-        <translation type="unfinished"></translation>
+        <translation>選択されたカード</translation>
     </message>
 </context>
 <context>
