@@ -152,9 +152,14 @@ Creating tmp file.</source>
     <message>
         <source>More info: http://mnemosyne-proj.sourceforge.net
 </source>
-        <translation>更多信息： http://mnemosyne-proj.sourceforge.net
+        <translation type="obsolete">更多信息： http://mnemosyne-proj.sourceforge.net
 </translation>
     </message>
+    <message>
+        <source>More info: http://mnemosyne-proj.org
+</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>AboutFrm</name>
@@ -383,7 +388,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>&amp;Preview</source>
-        <translation>预览(&amp;P)</translation>
+        <translation type="obsolete">预览(&amp;P)</translation>
     </message>
     <message>
         <source>Ctrl+P</source>
@@ -397,6 +402,10 @@ Creating tmp file.</source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Preview</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ChangeCategoryFrm</name>
@@ -497,7 +506,7 @@ Creating tmp file.</source>
     </message>
     <message>
         <source>Number of grade 0 cards to learn at once:</source>
-        <translation>一次学习0分卡片数量：</translation>
+        <translation type="obsolete">一次学习0分卡片数量：</translation>
     </message>
     <message>
         <source>Note: this is NOT the number of grade 0 cards you want to memorise *per day*</source>
@@ -515,6 +524,14 @@ Creating tmp file.</source>
         <source>&amp;Cancel</source>
         <translation>取消(&amp;C)</translation>
     </message>
+    <message>
+        <source>Learn new cards in random order</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Number of grade 0 cards to hold in your hand:</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemFrm</name>
@@ -694,6 +711,10 @@ so you might want to run </source>
         <source>&amp;Find</source>
         <translation>查找(&amp;F)</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="obsolete"></translation>
+    </message>
 </context>
 <context>
     <name>EditItemsFrm</name>
@@ -729,6 +750,10 @@ so you might want to run </source>
         <source>Alt+X</source>
         <translation>Alt+X</translation>
     </message>
+    <message>
+        <source>Alt+F</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ExportDlg</name>
@@ -906,7 +931,7 @@ so you might want to run </source>
     </message>
     <message>
         <source>Show &amp;answer</source>
-        <translation>显示答案(&amp;A)</translation>
+        <translation type="obsolete">显示答案(&amp;A)</translation>
     </message>
     <message>
         <source>Learn ahead of schedule</source>
@@ -932,6 +957,10 @@ so you might want to run </source>
         <source>All: </source>
         <translation>所有：</translation>
     </message>
+    <message>
+        <source>Show answer</source>
+        <translation type="unfinished">显示答案</translation>
+    </message>
 </context>
 <context>
     <name>MainFrm</name>
@@ -1418,6 +1447,34 @@ Happy learning!</source>
         <source>Grade</source>
         <translation>评分</translation>
     </message>
+    <message>
+        <source>No current card.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Grade:</source>
+        <translation type="unfinished">评分：</translation>
+    </message>
+    <message>
+        <source>Easiness:</source>
+        <translation type="unfinished">容易程度：</translation>
+    </message>
+    <message>
+        <source>Repetitions:</source>
+        <translation type="unfinished">重复次数：</translation>
+    </message>
+    <message>
+        <source>Lapses:</source>
+        <translation type="unfinished">错过次数：</translation>
+    </message>
+    <message>
+        <source>Days since last repetition:</source>
+        <translation type="unfinished">自从上次重复的天数：</translation>
+    </message>
+    <message>
+        <source>Days until next repetition:</source>
+        <translation type="unfinished">直到下次重复的天数：</translation>
+    </message>
 </context>
 <context>
     <name>StatisticsFrm</name>
@@ -1449,6 +1506,10 @@ Happy learning!</source>
         <source>&amp;OK</source>
         <translation>确认(&amp;O)</translation>
     </message>
+    <message>
+        <source>Current card</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>TipDlg</name>
